@@ -107,6 +107,7 @@ func TestTerraformStateReader_AWS_Resources(t *testing.T) {
 		{name: "Route 53 record - multiples zones, multiples records", dirName: "aws_route53_record_multiples", wantErr: false},
 		{name: "Route 53 record - empty records", dirName: "aws_route53_record_null_records", wantErr: false},
 		{name: "s3 full", dirName: "aws_s3_full", wantErr: false},
+		{name: "s3 bucket public access block", dirName: "aws_s3_bucket_public_access_block", wantErr: false},
 		{name: "RDS DB instance", dirName: "aws_db_instance", wantErr: false},
 		{name: "RDS DB Subnet group", dirName: "aws_db_subnet_group", wantErr: false},
 		{name: "Lambda function", dirName: "aws_lambda_function", wantErr: false},
@@ -195,6 +196,8 @@ func TestTerraformStateReader_AWS_Resources(t *testing.T) {
 		{name: "Launch configuration", dirName: "aws_launch_configuration", wantErr: false},
 		{name: "EBS encryption by default", dirName: "aws_ebs_encryption_by_default", wantErr: false},
 		{name: "LoadBalancer", dirName: "aws_lb", wantErr: false},
+		{name: "Classic load balancer", dirName: "aws_elb", wantErr: false},
+		{name: "ElastiCache Cluster", dirName: "aws_elasticache_cluster", wantErr: false},
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
