@@ -1,6 +1,6 @@
 package azurerm
 
-import "github.com/cloudskiff/driftctl/pkg/resource"
+import "github.com/snyk/driftctl/pkg/resource"
 
 func InitResourcesMetadata(resourceSchemaRepository resource.SchemaRepositoryInterface) {
 	initAzureVirtualNetworkMetaData(resourceSchemaRepository)
@@ -24,4 +24,5 @@ func InitResourcesMetadata(resourceSchemaRepository resource.SchemaRepositoryInt
 	initAzureImageMetaData(resourceSchemaRepository)
 	initAzureSSHPublicKeyMetaData(resourceSchemaRepository)
 	initAzurePrivateDNSCNameRecordMetaData(resourceSchemaRepository)
+	initAzureLoadBalancerRuleMetadata(resourceSchemaRepository)
 }
