@@ -90,6 +90,7 @@ var supportedTypes = map[string]ResourceTypeMeta{
 	"aws_s3_bucket_metric":                  {},
 	"aws_s3_bucket_notification":            {},
 	"aws_s3_bucket_policy":                  {},
+	"aws_s3_bucket_public_access_block":     {},
 	"aws_security_group": {children: []ResourceType{
 		"aws_security_group_rule",
 	}},
@@ -162,6 +163,8 @@ var supportedTypes = map[string]ResourceTypeMeta{
 	"aws_apigatewayv2_integration_response": {},
 	"aws_launch_template":                   {},
 	"aws_launch_configuration":              {},
+	"aws_elb":                               {},
+	"aws_elasticache_cluster":               {},
 
 	"github_branch_protection": {},
 	"github_membership":        {},
